@@ -1,8 +1,12 @@
 {-# LANGUAGE UndecidableInstances , FlexibleContexts , MultiParamTypeClasses , FlexibleInstances , GeneralizedNewtypeDeriving, TypeOperators, ScopedTypeVariables, CPP #-}
-#if defined(__GLASGOW_HASKELL__) && __GLASGOW_HASKELL__ >= 702
+#if __GLASGOW_HASKELL__ >= 702
 {-# LANGUAGE Trustworthy #-}
 #endif
 
+#ifndef MIN_VERSION_semigroups
+#define MIN_VERSION_semigroups(x,y,z) 1
+#endif
+
 -----------------------------------------------------------------------------
 -- |
 -- Module      :  Data.Semigroup.Reducer
@@ -25,14 +29,20 @@ module Data.Semigroup.Reducer
   , Count(..)
   ) where
 
+#if __GLASGOW_HASKELL__ < 710
 import Control.Applicative
+#endif
 
 import qualified Data.Monoid as Monoid
 import Data.Semigroup as Semigroup
 import Data.Semigroup.Foldable
 import Data.Semigroup.Instances ()
 import Data.Hashable
+
+#if __GLASGOW_HASKELL__ < 710
 import Data.Foldable
+#endif
+
 import Data.FingerTree
 
 import qualified Data.Sequence as Seq
@@ -112,7 +122,11 @@ instance Hashable Count where
 
 instance Semigroup Count where
   Count a <> Count b = Count (a + b)
+#if MIN_VERSION_semigroups(0,17,0)
+  stimes n (Count a) = Count $ fromIntegral n * a
+#else
   times1p n (Count a) = Count $ (fromIntegral n + 1) * a
+#endif
 
 instance Monoid Count where
   mempty = Count 0
